package pickfirstleaf

import "google.golang.org/grpc/balancer/pickfirst/pickfirstleaf"

Package pickfirstleaf contains the pick_first load balancing policy which will be the universal leaf policy after dualstack changes are implemented.

Deprecated: This package is deprecated. Please use the balancer/pickfirst package instead.

Index

Constants

const Name = "pick_first"

Name is the name of the pick_first_leaf balancer. Deprecated: Use the balancer/pickfirst package's Name instead.

Functions

func EnableHealthListener

func EnableHealthListener(state resolver.State) resolver.State

EnableHealthListener updates the state to configure pickfirst for using a generic health listener. Deprecated: Use the balancer/pickfirst package's EnableHealthListener instead.

Source Files

pickfirstleaf.go

Version
v1.77.0
Published
Nov 17, 2025
Platform
linux/amd64
Imports
2 packages
Last checked
1 minute ago

Tools for package owners.