grpcgoogle.golang.org/grpc/balancer/weightedroundrobin Index | Files | Directories

package weightedroundrobin

import "google.golang.org/grpc/balancer/weightedroundrobin"

Package weightedroundrobin provides an implementation of the weighted round robin LB policy, as defined in gRFC A58.

Experimental

Notice: This package is EXPERIMENTAL and may be changed or removed in a later release.

Index

Constants

const Name = "weighted_round_robin"

Name is the name of the weighted round robin balancer.

Functions

func SetBackendService

func SetBackendService(state resolver.State, backendService string) resolver.State

SetBackendService stores the backendService on the resolver state so that it can be used later as a label in wrr metrics.

Source Files

balancer.go config.go logging.go scheduler.go

Directories

PathSynopsis
balancer/weightedroundrobin/internalPackage internal allows for easier testing of the weightedroundrobin package.
Version
v1.79.3
Published
Mar 17, 2026
Platform
linux/amd64
Imports
23 packages
Last checked
23 seconds ago

Tools for package owners.