package internal
import "google.golang.org/grpc/balancer/weightedroundrobin/internal"
Package internal allows for easier testing of the weightedroundrobin package.
Index ¶
Variables ¶
var AllowAnyWeightUpdatePeriod bool
AllowAnyWeightUpdatePeriod permits any setting of WeightUpdatePeriod for testing. Normally a minimum of 100ms is applied.
TimeNow can be overridden by tests to return a different value for the current iserviceconfig.
Types ¶
type LBConfig ¶
type LBConfig struct {
EnableOOBLoadReport *bool `json:"enableOobLoadReport,omitempty"`
OOBReportingPeriod *string `json:"oobReportingPeriod,omitempty"`
BlackoutPeriod *string `json:"blackoutPeriod,omitempty"`
WeightExpirationPeriod *string `json:"weightExpirationPeriod,omitempty"`
WeightUpdatePeriod *string `json:"weightUpdatePeriod,omitempty"`
ErrorUtilizationPenalty *float64 `json:"errorUtilizationPenalty,omitempty"`
}
LBConfig allows tests to produce a JSON form of the config from the struct instead of using a string.
Source Files ¶
internal.go
- Version
- v1.74.2
- Published
- Jul 22, 2025
- Platform
- linux/amd64
- Imports
- 1 packages
- Last checked
- 17 minutes ago –
Tools for package owners.